@@ -22,7 +22,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
-__version__ = "0.3.39"
+__version__ = "0.3.40"
 __author__ = "nagev"
 __license__ = "GPLv3"
 
@@ -35,6 +35,7 @@ import json
 import logging
 from xml.etree import ElementTree
 
+early_py_version = sys.version_info[:2] < (2, 7)
 decode_if_py3 = lambda x: x.decode("utf8")
 
 if sys.version_info[:2] >= (3, 0):
@@ -178,8 +179,19 @@ def _extract_smap(map_name, dic, zero_idx=True):
         smap = smap[0] if zero_idx else smap
         smap = smap.split(",")
         smap = [parse_qs(x) for x in smap]
-        smap = [{k: v[0] for k, v in x.items()} for x in smap]
-        return smap
+
+        if not early_py_version:
+            return [{k: v[0] for k, v in x.items()} for x in smap]
+
+        else:
+            # Python 2.6 compatibility
+            r = []
+            for x in smap:
+                z = {}
+                for k, v in x.items():
+                    z[k] = v[0]
+                r.append(z)
+            return r
 
     return []
 
@@ -638,6 +650,11 @@ class Stream(object):
 
         status_string = ('  {:,} Bytes [{:.2%}] received. Rate: [{:4.0f} '
                          'KB/s].  ETA: [{:.0f} secs]')
+
+        if early_py_version:
+            status_string = ('  {0:} Bytes [{1:.2%}] received. Rate:'
+                                 ' [{2:4.0f} KB/s].  ETA: [{3:.0f} secs]')
+
         response = g.opener.open(self.url)
         total = int(response.info()['Content-Length'].strip())
         chunksize, bytesdone, t0 = 16384, 0, time.time()
@@ -1056,7 +1073,8 @@ class Pafy(object):
         self._author = pl_data.get("author")
         self._length = int(pl_data.get("length_seconds", 0))
         self._rating = pl_data.get("rating", 0.0)
-        self._viewcount = int(pl_data.get("views", 0).replace(",", ""))
+        self._viewcount = "".join(re.findall("\d", pl_data.get("views", "0")))
+        self._viewcount = int(self._viewcount)
         self._thumb = pl_data.get("thumbnail")
         self._description = pl_data.get("description")
         self.playlist_meta = pl_data
@@ -1125,6 +1143,7 @@ def get_playlist(playlist_url, basic=False, gdata=False, signature=False,
             description=v.get('description'),
             encrypted_id=v.get('encrypted_id'),
             time_created=v.get('time_created'),
+            time_updated=v.get('time_updated'),
             length_seconds=v.get('length_seconds')
         )
 
